RuntimeError

Enum RuntimeError 

pub enum RuntimeError {
Show 14 variants Connect(Error), ImagePull { image: String, source: Error, }, Start(Error), Stop { id: String, source: Error, }, Remove { name: String, source: Error, }, Inspect { id: String, source: Error, }, NotFound(String), Timeout { operation: &'static str, after: Duration, }, LogStream(Error), NetworkCreate { name: String, source: Error, }, NetworkRemove { name: String, source: Error, }, Build(Error), BuildFailed(String), InvalidSpec(String),
}
Errors raised by a crate::ContainerRuntime implementation.

Variants



Connect(Error)

The runtime could not establish a connection to the underlying container daemon (Docker socket, Podman API, …).



ImagePull

Pulling an image from the registry failed.

Fields

image: String

The image reference that the runtime tried to pull.

source: Error

Underlying error from the container daemon.



Start(Error)

The runtime refused to start the container.



Stop

The runtime refused to stop a container.

Fields

id: String

Identifier of the container that could not be stopped.

source: Error

Underlying error from the container daemon.



Remove

The runtime refused to remove a container.

Fields

name: String

Name of the container that could not be removed.

source: Error

Underlying error from the container daemon.



Inspect

The runtime could not inspect a container.

Fields

id: String

Identifier of the container that could not be inspected.

source: Error

Underlying error from the container daemon.



NotFound(String)

The container does not exist on the daemon.



Timeout

A blocking operation exceeded its allotted time budget.

Fields

operation: &'static str

Short name of the operation that timed out.

after: Duration

Configured timeout.



LogStream(Error)

Streaming logs from a container failed mid-flight.



NetworkCreate

Creating the per-project Docker bridge network failed.

Fields

name: String

Name of the network that could not be created.

source: Error

Underlying error from the container daemon.



NetworkRemove

Removing the per-project Docker bridge network failed.

Fields

name: String

Name of the network that could not be removed.

source: Error

Underlying error from the container daemon.



Build(Error)

Building an image from a Dockerfile failed.



BuildFailed(String)

The BuildKit builder reported a failure in its progress stream.



InvalidSpec(String)

The provided crate::ContainerSpec is structurally invalid.