ContainerStatus

Enum ContainerStatus 

pub enum ContainerStatus {
    Starting,
    Running,
    Healthy,
    Unhealthy,
    Stopped {
        exit_code: Option<i32>,
    },
}
Lifecycle status reported by the runtime when inspecting a container.

Variants



Starting

The runtime has accepted the start request but the container is not yet running.



Running

The container is running and either has no healthcheck or has not produced a healthcheck result yet.



Healthy

The container is running and reports a healthy healthcheck.



Unhealthy

The container is running and reports an unhealthy healthcheck.



Stopped

The container has exited.

Fields

exit_code: Option<i32>

Exit code reported by the container, when known.